==> vtk6-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkCylinder.java <==
// java wrapper for vtkCylinder object
//

package vtk;
import vtk.*;

public class vtkCylinder extends vtkImplicitFunction
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double EvaluateFunction_2(double id0[]);
  public double EvaluateFunction(double id0[])
    { return EvaluateFunction_2(id0); }

  private native double EvaluateFunction_3(double id0,double id1,double id2);
  public double EvaluateFunction(double id0,double id1,double id2)
    { return EvaluateFunction_3(id0,id1,id2); }

  private native void EvaluateGradient_4(double id0[],double id1[]);
  public void EvaluateGradient(double id0[],double id1[])
    { EvaluateGradient_4(id0,id1); }

  private native void SetRadius_5(double id0);
  public void SetRadius(double id0)
    { SetRadius_5(id0); }

  private native double GetRadius_6();
  public double GetRadius()
    { return GetRadius_6(); }

  private native void SetCenter_7(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_7(id0,id1,id2); }

  private native void SetCenter_8(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_8(id0); }

  private native double[] GetCenter_9();
  public double[] GetCenter()
    { return GetCenter_9(); }

  public vtkCylinder() { super(); }

  public vtkCylinder(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkCylinder.java <==
// java wrapper for vtkCylinder object
//

package vtk;
import vtk.*;

public class vtkCylinder extends vtkImplicitFunction
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native double EvaluateFunction_2(double id0[]);
  public double EvaluateFunction(double id0[])
    { return EvaluateFunction_2(id0); }

  private native double EvaluateFunction_3(double id0,double id1,double id2);
  public double EvaluateFunction(double id0,double id1,double id2)
    { return EvaluateFunction_3(id0,id1,id2); }

  private native void EvaluateGradient_4(double id0[],double id1[]);
  public void EvaluateGradient(double id0[],double id1[])
    { EvaluateGradient_4(id0,id1); }

  private native void SetRadius_5(double id0);
  public void SetRadius(double id0)
    { SetRadius_5(id0); }

  private native double GetRadius_6();
  public double GetRadius()
    { return GetRadius_6(); }

  private native void SetCenter_7(double id0,double id1,double id2);
  public void SetCenter(double id0,double id1,double id2)
    { SetCenter_7(id0,id1,id2); }

  private native void SetCenter_8(double id0[]);
  public void SetCenter(double id0[])
    { SetCenter_8(id0); }

  private native double[] GetCenter_9();
  public double[] GetCenter()
    { return GetCenter_9(); }

  private native void SetAxis_10(double id0,double id1,double id2);
  public void SetAxis(double id0,double id1,double id2)
    { SetAxis_10(id0,id1,id2); }

  private native void SetAxis_11(double id0[]);
  public void SetAxis(double id0[])
    { SetAxis_11(id0); }

  private native double[] GetAxis_12();
  public double[] GetAxis()
    { return GetAxis_12(); }

  public vtkCylinder() { super(); }

  public vtkCylinder(long id) { super(id); }
  public native long   VTKInit();

}
